#
# spec file for package kubescape
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

Name:           kubescape
Version:        3.0.1
Release:        1.1
Summary:        Tool providing a multi-cloud K8s single pane of glass
License:        Apache-2.0
URL:            https://github.com/armosec/kubescape
Source:         kubescape-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.19

%description
Kubescape is a K8s open-source tool providing a multi-cloud K8s single pane of glass, including risk analysis, security compliance, RBAC visualizer and image vulnerabilities scanning. Kubescape scans K8s clusters, YAML files, and HELM charts, detecting misconfigurations according to multiple frameworks (such as the NSA-CISA , MITRE ATT&CK®), software vulnerabilities, and RBAC (role-based-access-control) violations at early stages of the CI/CD pipeline, calculates risk score instantly and shows risk trends over time. It became one of the fastest-growing Kubernetes tools among developers due to its easy-to-use CLI interface, flexible output formats, and automated scanning capabilities, saving Kubernetes users and admins’ precious time, effort, and resources. Kubescape integrates natively with other DevOps tools, including Jenkins, CircleCI, Github workflows, Prometheus, and Slack, and supports multi-cloud K8s deployments like EKS, GKE, and AKS.

%prep
%autosetup -p 1 -a 1

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -tags="gitdisabled" \
   -ldflags="-w -s -X github.com/kubescape/kubescape/v2/core/cautils.BuildNumber=v%{version}" \
   -o kubescape

%install
# Install the binary.
install -D -m 0755 %{name} "%{buildroot}/%{_bindir}/%{name}"

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%changelog
* Wed Nov  1 2023 kastl@b1-systems.de
- Update to version 3.0.1:
  * bump logger version
  * Pretty up the pretty-printer. (#1451)
  * Update flags (#1462)
  * bump pkg
  * avoid adding duplicate related resource IDs
* Mon Oct 23 2023 kastl@b1-systems.de
- Update to version 3.0.0:
  * Bump v3 (#1449)
  * Cloud provider detection (#1448)
  * Preparing Kubescape for v3 (#1403)
  * Support backend access key (#1404)
  * Restructure img cmd (#1398)
  * add env-dependencies-policy to security insights
  * print result to stdout when format argument specified (#1438)
* Thu Oct 19 2023 kastl@b1-systems.de
- Update to version 2.9.2:
  * add more missing permissions for actions
  * set log to error
  * rm if statement
  * replace driver name
  * actions needs write on id-token in pr-scanner
  * bump deps for vulnerabilities
  * fixing GH actions permissions
  * use distroless debug as entrypoint.sh requires a shell
  * remove extra permissions on GH action
  * add ArtifactHub to README
  * add FOSSA badge to README
  * build windows exec without libgit
  * use go-gitlog as an alternative to git2go (#1393)
  * use ControlConfigInputs, deprecate ConfigInputs (#1419)
  * add top level permissions: read-all for openssf
  * correct security-insights stage -> status
  * Fix in the README for changelog name
  * Adding project security and governance as per maintainer
    decision
  * Update README.md
  * Create scorecard.yml
  * Bump golang.org/x/net from 0.14.0 to 0.17.0 in /httphandler
  * use correct variable for IMAGE_TAG
  * drop build tags for tests (will soon deprecate them)
  * add missing dependency on retag in binary-build
  * Removed the Codesee workflow
  * force docker-build in absence of release label
  * Adding check-secret to build image wf
  * Bump github.com/cyphar/filepath-securejoin from 0.2.3 to 0.2.4
  * split failedPath to deletePaths and reviewPaths (#1402)
  * add Openssf badge (#1400)
  * Support control cluster from cli (#1391)
  * disable rate limiting for storage client
  * Separate docker builds for kubescape and kubescape-cli (#1390)
  * Save scan results in storage and support scanning a deleted
    resource (#1376)
  * add new line (#1389)
  * fix: format headers (#1383)
  * remove ARMO server url
  * feat: darken table borders
  * fix setting context name in httphandler
  * revert e2e test branch (#1373)
  * print up until 4 imgs
  * Update installation.md to add instructions to install a
    previous version via SH
* Wed Sep  6 2023 kastl@b1-systems.de
- Update to version 2.9.1:
  * Fix scan command (#1369)
  * validate sarif format
  * bump version (#1368)
  * move context flag to root (#1367)
  * Error Fixed when downloading on azure cloud vm environment
    (#720)
  * Logger fixes (#1362)
  * Service discovery (#1359)
  * core(cmd): adding corrections to cmd (#1357)
  * Beautify install.sh script logs (#1356)
  * Refactor backend integration (#1355)
  * fix panic & provide msg (#1353)
  * Improve cluster scan cli (#1352)
  * support paths from related resources (#1351)
  * Improve logs (#1349)
  * improve cli output (#1347)
  * fix panic and improve logs (#1344)
  * fix: icons formatting (#1343)
  * bump k8s-interface version (#1345)
  * Support unified configuration (#1304)
  * Create dependabot.yaml
* Wed Sep  6 2023 kastl@b1-systems.de
- there were no releases betweeen 2.3.9 and 2.9.0
- Update to version 2.9.0:
  * feat: migrate fatih/color to gchalk
  * Update logs (#1340)
  * feat: add table heading colors (#1321)
  * use distroless base image (#1338)
  * feat: improve pretty logger (#1311)
  * feat: add short table (#1292)
  * feat: change colors library (#1316)
  * chore: update docs build.ps1 (#1299)
  * feat: add unicode table (#1285)
  * scan per namespace (#1337)
  * Implementing container image name normalization built-in
    function for Rego (#1334)
  * Support scanning scope (#1293)
  * Hotfix for version 2.3.8 (#1333)
  * Code refactor (follow up to PR #1300) (#1323)
  * fix(httphandler): pin breaking anchore dependency
  * Update PR workflow (#1330)
  * Update codesee-arch-diagram.yml
  * Update 00-pr-scanner.yaml
  * fix submit time
  * New output (#1320)
  * Adding pr-agent
  * Install the CodeSee workflow. Learn more at
    https://docs.codesee.io
  * add prints to smoketest
  * docs(imagescan): provide package-level docs
  * chore(imagescan): create vuln db with dedicated function
  * chore(imagescan): add dependencies to httphandler
  * chore(imagescan): include dependencies
  * feat(imagescan): add an image scanning command
  * remove scan workload command
  * Scanning a single resource (#1300)
  * reset head (#1306)
  * bump opa-utils
  * bump opa-utils, k8s-interface and armoapi-go
  * fix: negative compliance score
  * linter correction
  * review corrections
  * update armo docs
  * git recognition for empty directory for test
  * add error handle when there are no scan to trigger since the
    directory not contain any relevant scanning files
  * fix: kubescape list controls
* Wed Jul 26 2023 kastl@b1-systems.de
- Update to version 2.3.8:
  * add print in the cli to which version the kubescape was update
    (#1295)
  * feat: add build.ps1
  * fix: yamlhandler error handling
  * tests(fixhandler): remove tests of an unexported sanitization
    method
  * docs(fixhandler): follow Go Doc comments convention in
    sanitization func
  * refactor(fixhandler): sanitize YAML inside ApplyFixToContent
  * tests(fixhandler): fail test if unable to open test data file
  * style(fixhandler): newlines and spacing
  * support related objects (#1272)
  * allow adding a fw name when running all (#1286)
  * fix: --- kubescape fix
  * cache control inputs
  * Remove website folder
  * fix: stuck spinner
  * initial implementation of OpenTelemetry metrics collection
    (#1269)
  * time-based cached policies
* Thu Jul  6 2023 kastl@b1-systems.de
- Update to version 2.3.7:
  * submit file scanning
  * Update grafana-kubescape-dashboard.json
  * update messaging based on Oshrats comments
  * update submit message
  * deprecate the login flags
  * ignore adaptors if credentials are not set
  * deprecate host-scan-yaml flag
  * remove unused file
  * Changed Assistance Remediation to Assited Remediation
  * Deprecated host-scanner
  * fxi test jsons
  * update regolibrary to v1.0.286-rc.0
  * Update docs/providers/armo.md
  * Updating overview
  * fixed wording
  * Split the installation command from scanning
  * update installation steps
  * initialize ns in case we don't have one in YAML
* Fri Jun 16 2023 kastl@b1-systems.de
- Update to version 2.3.6:
  * chore: remove refs to deprecated io/ioutil
  * fix: CVE-2023-28840 CVE-2023-28841 CVE-2023-28842
    CVE-2022-41723 etc. (#1221)
  * Fix statuses - Manual review and Requires configuration (#1251)
* Mon Jun 12 2023 kastl@b1-systems.de
- Update to version 2.3.5:
  * correcting the formating of the table in pdf output (#1244)
  * core(metrics api): Update API default behavior (#1250)
  * fix: update host-scanner version
  * fix: remove deprecated endpoint
  * wip: remove secretKey and clientID from list cmd
  * wip: add example for exclude-namespaces flag
* Sun May 28 2023 kastl@b1-systems.de
- Update to version 2.3.4:
  * update kubescape/go-git-url version
  * feat: add log coupling for hostsensorutils
  * fix(hostsensorutils): add finalizers deletion
  * fix(hostsensorutils): reduce periods of readiness probe
  * fix: move host-scanner to kubescape namespace
  * update opa-utils
  * bump opa-utils version for memory optimizations
  * Add back new line at the end of the file
  * Removed instructions and added the wiki link
  * Added instructions to setup kubescape locally
  * Fix downloading arm64 binary for kubescape
* Tue May 16 2023 kastl@b1-systems.de
- Update to version 2.3.3:
  * Revert "Deprecate kubescape-windows-latest"
  * start with a new context, extracting span from request
  * updating readme file to support compliance
  * Deprecate kubescape-windows-latest
* Mon May 15 2023 kastl@b1-systems.de
- Update to version 2.3.2:
  * Control parallelism of opa rule processing by env var (#1230)
  * update go version 1.19->1.20
  * add compliance score system test
  * Add ref to workflow dispatch
* Wed May  3 2023 kastl@b1-systems.de
- Update to version 2.3.1:
  * add test
  * if the response is empty, return an empty string
  * Make powershell Windows installation user path available
    immediately
  * Update installation script
* Tue May  2 2023 kastl@b1-systems.de
- Update to version 2.3.0:
  * invoke only if the repository owner is kubescape
  * Revert install.ps1 change, to update after release
  * Add kubescape.exe to the release assets
  * change basic auth username to x-token-auth
  * rerun workflows
  * ci: update before install packages
  * add compliance score to new field in controls for backward
    compatibility
  * fix(hostsensorutils): fix indentation of probe attributes
  * add compliance-threshold, deprecate fail-threshold (#1197)
  * wip: fixed github actions
  * wip: update fix command example
  * fix: remove outdated enpoints
  * Revert change to install.sh
  * update opa-utils version for fix in compliance score
  * Update snap installation
  * update opa-utils version
  * add compliance-threshold, deprecate fail-threshold
  * Move Building to wiki and installation back to docs
  * Move installation instructions to wiki
  * nit
  * Add more error check
  * Add unit testcase
  * S1023: redundant break statement (gosimple)
  * feat(sarif): add fix object in generated reports
  * Invoke workflow to update github action
  * Fix: Empty Frameworks Column when listing controls
  * fix: broken link
  * fix: broken link
  * Change wf (#1190)
  * set default report time
  * Invoke workflow to update after release
  * fix(fix): mixed up change list
  * Add ARM64 binary installation
  * Resume test core pkg under ubuntu arm64
  * Disable multi-platform test with commits
  * merge pr scanner build into binary-build-and-e2e-tests
  * Fix naming
  * Disable core pkg test for ubuntu arm64
  * add cross compilation for ubuntu arm64
  * add cross compilation for mac m1
  * adding compliance score updates (#1181)
  * comment failing test because of many requests
  * update version k8s-interface for cloud resources
  * update version k8s-interface for cloud resources
* Mon Apr  3 2023 kastl@b1-systems.de
- Update to version 2.2.6:
  * delete BUILD_AND_TEST_LOCAL_KUBESCAPE_CLI input for
    b-binary-build-and-e2e-tests wf
  * Add new meeting location
  * test: fix test with new function argument
  * feat: add progress bar during cloud resources download
  * clean code
  * load account details
  * update host scanner image tag
  * updated createTenant path (#1166)
  * refact(hostsensorutils): unexported fields that don't need to
    be exposed
  * fix shellcheck warning and info
  * test(utils): introduced internal/testutils package to factorize
    testing utilities
  * addressed review from David: reverted on unconditional loop
    exit
  * refact(host-sensor): refactors the host sensor
  * perf(opaprocessor): run OPA rule compilation and evaluation in
    parallel
  * refact(getter): refactor the KS Cloud client
  * Revert "added validation for if ORIGIN_TAG=null"
  * added validation for if ORIGIN_TAG=null
  * check KUBESCAPE_EXEC is not empty before deletion
  * change concurrency in 00-pr-scanner
  * remove merge action
  * core(logs): Enhance logs (#1158)
  * change trigger for wf
  * changed ks_branch to release
  * moved the output TEST_NAMES to wf-preparation job (was
    check-secret job) and added step export_tests..
  * fixed syntax error
  * fixed syntax error
  * added input to make the binary build and test dynamic
  * added CHECKOUT_REPO input parameter
  * update host scanner image tag
  * change failed to submit message
  * Signed-off-by: David Wertenteil <dwertent@armosec.io>
  * fix references to kubectl in completion help
  * Set scanning event
  * replace error by warning
  * Added context to HandleResults
  * add dependencies to httphandler
  * upgrade opa-utils and armo api
  * Add prompt for removing old way of installation
  * Clean uninstall of old installation
  * Change installation path to ~/.kubescape/bin
  * bump go-logger (#1144)
  * Update CONTRIBUTING.md
  * feat: integrate support to retrieve eks policies
  * Revert add '.exe' to Win release binary
  * ci(release): fix publishing krew plugin; add .exe suffix to Win
    binary
* Mon Mar 13 2023 kastl@b1-systems.de
- Update to version 2.2.5:
  * initialize context in Prometheus handler
  * fixup unit test: error handling
  * test(hostsensorutils): added unit tests to the
    hostsensorutils package
  * test(reports): adds unit test to the report receiver
* Mon Mar 13 2023 kastl@b1-systems.de
- Update to version 2.2.4:
  * chore(lintin): run another pass of linting with the rules
    already in place
  * removed otel middleware from some APIs
  * wip: update UTMs & display UTM only on first scan
  * wip: do not add message when account ID is empty
  * Do not display  URL when message is empty
  * wip: removed unused code
  * wip: update link in docs
  * refactor: update node scanner daemonset tolerations
* Mon Mar 13 2023 kastl@b1-systems.de
- Update to version 2.2.3:
  * ci: pin workflows versions to fixed commits
  * fix(hostsensorsutils): remove hostNet and hostPort from
    deployment
  * added clusterName to otel initialization
* Mon Mar 13 2023 kastl@b1-systems.de
- Update to version 2.2.2:
  * Move GITHUB_REF to the krew step
  * add unitsests to new behavior
  * Do not print table when logger level is warn
  * marking structs that are implementing IPrinter
  * wip: re-arange struct
  * Override GITHUB_REF env when releasing krew
  * removing host scanner otel env
  * Update rbac-utils pkg
  * fix(processorhandler): reduce GC pressure
* Mon Mar 13 2023 kastl@b1-systems.de
- Update to version 2.2.1:
  * fix(hostsensorutils): improve namespace deletion in
    host-scanner lifecycle
  * update opa pkg to 238
  * update opa pkg
  * Fix HTML output (#1111)
  * bump go-git-url (#1110)
  * fix macos build - add missing pkg-config
  * style(hostsensorutils): simplify code with gofmt
  * fix(build): LICENSE file
  * fix(README): broken links
  * enable krew plugin publishing action
  * chore: Remove an unwanted file
  * fix(hostsensorutils): improve cloud provider detection
  * generated rego policy json fixture file, short-circuited call
    to github when fixture is here
  * test(getters): added unit tests for utilities
  * test(getters): added unit tests to the kubescape API client
  * tests(cautils): added unit tests for released policy
* Mon Mar 13 2023 kastl@b1-systems.de
- Update to version 2.2.0:
  * Statuses (#1016)  (#1082)
  * modify plugin description for krew approval
  * Revert "fix: add check to skip controlplaneinfo in case of
    cloud providers"
  * fix: add check to skip controlplaneinfo in case of cloud providers
  * docs(contributing): add semantic commit messages best practice
* Mon Mar 13 2023 kastl@b1-systems.de
- Update to version 2.1.3:
  * Loading kubeconfig name from env when running ms (#1089)
  * removed unwnated span (#1088)
  * fix #1025 (#1087)
  * Default frameworks (#1085)
  * update logs in some resource getters (#1071)
  * don't add host scanner as excluded ns, use exception instead
    (#1083)
  * Fixes for krew plugin submission (#1081)
  * GitRegoStore moved to Regolibrary (#1058)
* Mon Mar 13 2023 kastl@b1-systems.de
- Update to version 2.1.1:
  * Renaming the files (#1079)
* Mon Mar 13 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 2.1.0:
  * Add cosign functions for signature checking
  * Add progress bar for control processing
  * Add OTEL with uptrace client
  * Changed default JSON output to v2
* Mon Mar 13 2023 kastl@b1-systems.de
- Update to version 2.0.182:
  * setCloudMetadata only when scanning a cluster
  * Initial documentation update upon joining the CNCF (#1020)
* Mon Mar 13 2023 kastl@b1-systems.de
- Update to version 2.0.181:
  * update opa-utils pkg with URL parsing fixed
* Mon Mar 13 2023 kastl@b1-systems.de
- Update to version 2.0.180:
  * Release  (#1000)
* Mon Mar 13 2023 kastl@b1-systems.de
- Update to version 2.0.179:
  * update httphandler go mod
  * update go-git pkg
  * update config scanning path
  * Update core/pkg/resultshandling/results.go
  * feat: notify about writing to an output file in PrettyPrinter
  * style: tidy up the PDFPrinter
  * style: shorten receiver names in JUnitPrinter
  * style: shorten receiver names in JSONPrinter
  * style: shorten receiver names in HTML Printer
  * style: shorten receiver names in PrettyPrinter
  * docs: clarify new meaning of the `--format` CLI flag
  * feat: always print to (T)UI using PrettyPrinter
  * style: `GetFormats` → `Formats`
  * style: `go fmt` the project
  * style: shorten receiver names in ResultsHandler
  * style: shorten receiver names for Prometheus printer
  * refactor: tidy up printing to multiple outputs
  * fix: revert the overriden ScanningTarget when submitting
    reports
  * Add logs for some formats
  * Update core/pkg/resultshandling/printer/printresults.go
  * Handle Output Extensions Gracefully
  * Add logs for some formats
  * Support getting outputs in multiple formats
  * minor fix
  * update go mod in httphandler
  * Breakdown cloud-cluster name
  * Fixed test
  * DownloadInfo, PolicyIdentifier add Identity, remove ID and Name
  * opa-utils v0.0.216
  * opa-utils v0.0.216
  * ignore resource if it is not found
  * remove image vuln warning
  * remove --verbose flag from default
  * remove emoji from display
  * Adopt CNCF Code of Conduct.
  * Update maintainers
  * validate downloaded framework
  * Revert "Excluding controlPlaneInfo from error message in case
    no data recieved."
  * chore: Explicit set allowPrivilegeEscalation=true
  * test fix
  * test fix
  * control scan by id
  * download control only by id
  * minor
  * revert opa-utils version
  * patch to filter out "controlPlaneInfo" from error messages in
    case no data
  * chore(style): renamed versioned packages to stick to idiomatic
    conventions
  * go mod tidy
  * update opa-utils  v0.0.209
  * All prints and outputs to get data by control ID
  * added GitLab repo scanning support
* Mon Mar 13 2023 kastl@b1-systems.de
- Update to version 2.0.178:
  * change linux runner to 20.04 instead of ubuntu-latest (#960)
* Mon Mar 13 2023 kastl@b1-systems.de
- Update to version 2.0.177:
  * Fix Junit format
  * Added Kubescape flow.drawio
  * remove tag latest
  * fixed scanning example
  * do not build dev images
  * fixed echo command
  * go mod tidy ancillary modules manifest
  * move parsing of version to GetVersion
  * fix(giturlparse): fixes panic on unexpected gitlab remote URL
  * fixed typo
  * Update cmd/scan/framework.go
  * deprecate set-output
  * testing release
  * run build only if secret is set
  * tagging only main image as latest
  * update repository scanning URL
  * update hostscanner version
  * added logs of host scanner version
  * fix link for cis controls in html output
  * go mod tidy
  * minor fix
  * update opa-utils functions
  * Update host-scanner image version to v1.0.38
  * Handle Invalid Formats
  * Support in new host-scanner endpoint - cloudProviderInfo
  * Getting cloud provider from gitversion of discovered API
    version
  * Getting cluster name from context
  * supporting client type from env
  * update examples
  * Added "CloudProvider" to postureControlInputs
  * fix: filepath.Dir requires trailing slash
  * Adding frameworks column to control command
  * PER-633 support loading exceptions from cache
  * PER-550 Support loading attack tracks from cache
  * stash
  * omit raw resources flag in json output
  * Revert PR #802 to the old junit format
  * Fix RootDir Info
  * replace src with RelSrc
  * Relative Path When scanning Local Repos
* Mon Mar 13 2023 kastl@b1-systems.de
- Update to version 2.0.176:
  * test build flow
  * fixed docker build to support arm
  * replace control 0006 by 0048
  * continue when resource not found
  * Pretty Print frameworks and exceptions
  * Shift GetControlLink to cautils
  * remove from smoke test
  * Do not exit on error
  * Updating json v1 deprecation message
  * Deprecate rbac submit
  * adding Remediation to message
  * Updated and Used GetControlLink
  * Modified Link Convention for CIS Controls
  * Improve Code Quality
  * Pretty Print Controls made Pretty
  * Update rbac-utils tag
  * Fix go.mod in httphandler
  * Update k8s-interface version
  * remove deprecated ioutil package
  * Invalid Format Error
  * Solved: Empty Lines before printing Controls
  * add IDs to controls list, deprecate id flag
  * fixing readme (#899)
  * Fix reading frameworks from local file
* Mon Mar 13 2023 kastl@b1-systems.de
- Update to version 2.0.175:
  * retrieve submit flag
  * fixed indentation
  * updated go.mod
  * added line and column information when using the sarif format
  * fix dependencies
  * fix go.sum
  * updated go.mod
  * Remove irrelevant code
  * Adding Log in Caller Function
  * remove --submit from msg when not submitted
  * Add support to exceptions on repo (files) scan
  * remove platforms build
  * removed log
  * Added Path variables for credentials
  * Error Info Added
  * Update core/core/initutils.go
  * Add go sum
  * Fix go mod and go sum
  * Support downloading system-exception from GitHub
  * feat: support the SARIF output format
  * Fix when running with include or exclude namespace scanning
    only namespaced scope
  * PER-335 Fix comments
  * PER-335 Add comment
  * PER-335 Remove submit option from kubescape docs
  * Store default URLs in cache
  * PER-335 Removing support for submitting results without
    accountID
  * update cmd functionality added
  * update cmd functionality added
  * removed getLastScanId function
  * changed name and added readme
  * fixed
  * Added the required changes
  * Made the required changes
  * added adaptor
  * Added the comments for update command
  * auto pick the OS of the usersystem
  * Added the update command for kubescape
  * Update rootinfo.go
  * Update root.go
  * Delete kubeconfig.go
  * Rename kubeconfig to kubeconfig.go
  * Create kubeconfig
  * Delete kubeconfig
  * Create kubeconfig
  * Update README.md
* Mon Mar 13 2023 kastl@b1-systems.de
- Update to version 2.0.174:
  * update hostsensor version
  * commented out tests which made actual http calls
  * Adding links to readme
  * Update README.md
  * APIServerInfo resource added to the scan
  * Adopt custom cluster name
  * Update go.mod
  * Migrate to yaml.v3
  * cleaning from unused branches
  * Workflow call testing (#7)
  * testing gh actions
  * testing gh actions
  * host scanner with fixed version
  * update logs
  * change user to ks
* Mon Mar 13 2023 kastl@b1-systems.de
- Update to version 2.0.173:
  * use os path join in build file
  * adding github token
  * comment out image release
  * Store default URLs in cache (#875)
  * removed path from dockerfile
  * fixed typo
  * Fixed host-sensor control plane info collecting
  * following review
  * Support for getting backend URLs from ENV
  * Upgrade opa dependency
  * Added `controlPlaneInfo` host-sensor endpoint
  * Adopt custom cluster name (#862)
  * feat: add `--kubeconfig` flag (#858)
  * Use workflow_call (#859)
  * update path env var
  * Add arch diagrams (#857)
  * Update python build file
  * Update logs (#854)
  * Addition of Cosign for image signing (#826)
  * Fix typos, linting errors of markdown file, modify the content
    to make it more concise (#820)
  * Correcting Punctuation (#849)
  * Refactoring of Code Base (#853)
  * Merge branch 'master' into dev
  * feat: unify severity threshold into one CLI flag (#838)
  * Scan Kustomize Directory (#795)
  * add flag validation for --account-id (#605) (#793)
  * fixed attack tracks loading logic
  * fixed merge
  * fixed welcome message
  * remove unsupported installation method
  * typo in .gitignore file (#833)
  * Fix merge conflict
  * Per 307 fail on severity counters (#831)
  * Issue 613 cluster name (#783)
  * Prioritization (#815)
  * removed the extra 'download' word from the example (#810)
  * Print line separator only if some controls failed (#813)
  * update AdoptClusterName
  * Print line separator only if some controls failed
  * Edit Junit output (#802)
  * commened out prioritization logic
  * Remove windows extension build (#775)
  * remove windows exe extension
  * Update host scanner image  (#774)
  * update scanner image
  * Option to force enable color output (closes #560) (#767)
  * bump opa-utils to 181
  * Fixed: Kubescape fails to authenticate remote private Github
    repo (#721)
  * update logger version (#773)
  * update logger version
  * Merging typo fixes from master (#772)
  * Added resource prioritization information, raw resource will be
    sent on the result object
  * Change formatting to %%s
  * Print chart name log when fail to generate
  * update go.mod
  * Added fixed control input
  * Update completion.go
  * Update core/pkg/resourcehandler/filesloader.go
  * Fix scanning ListObj following reviews
  * Handle with issues  caused by updating opa-utils
  * Fix issues according to review
  * docs(readme): Star → star
  * gramatical improvements
  * Support scanning several files
  * improved icon of kubescape in readme
  * override infoMap only if it's not nil
  * Broken links fix in roadmap.md
  * Fix go mod in httphandler pkg
  * Fix issue for scanning list obj
* Mon Mar 13 2023 kastl@b1-systems.de
- Update to version 2.0.172:
  * Release (#844)
  * build killercoda playground added (#843)
* Mon Mar 13 2023 kastl@b1-systems.de
- Update to version 2.0.171:
  * Enhancing CLI flags (#835)
  * Update README.md (#827)
  * Fixed typos on multiple files (#808)
  * Fixed typos in roadmap.md (#800)
  * Update README.md (#804)
  * fixed some typo mistakes (#786)
  * fixed typos (#777)
  * Fixed typos in contribute.md (#779)
  * Update README.md (#782)
  * Publishing community meetings (#781)
* Mon Mar 13 2023 kastl@b1-systems.de
- Update to version 2.0.170:
  * Hot fix - Revert report structure (#776)
* Mon Mar 13 2023 kastl@b1-systems.de
- Update to version 2.0.169:
  * Fixed InfoMap usage  (#680)
  * Update PULL_REQUEST_TEMPLATE.md
  * fixed the typo in docs/index.html
  * Fixed some typos in feature_request.md
  * modified PR template
  * build.py is modified
  * Automatically Close "Typo" labelled Issue
  * roadmap.md file is modified
  * Added alpine tag
  * Fixed readme
  * Added link to code of conduct file
  * Updated README.md file
  * some grammar mistake is corrected in PULL_REQUEST_TEMPLATE.md
    file
  * fixed typos
  * docs : added gitpod badge in readme.md
  * punctuation changes
  * grammar error fixer in CONTRIBUTING.md
  * typo: In the title and h1 element
  * Fixed Typos in examples/exceptions/README.md
  * Update aws.sh
  * Update container-image-vulnerability-adaptor.md
  * fix typos
  * greetings
  * Update close-typos-issues.yaml
  * auto close typo issues
  * typo correction: for better code readability
  * Update README.md
  * Adding "open for contribution" tickets in the team intro
    section
  * small reame changes
  * removing ARMO from Kubescape logo
  * Updating high level roadmap
  * Update README.md
  * Update CONTRIBUTING.md
  * Update roadmap.md
  * Corrected grammatical errors
  * Edited few words
  * Edited here as well
  * Edited few words
* Mon Mar 13 2023 kastl@b1-systems.de
- Update to version 2.0.168:
  * Fixing building section links
  * Fixed readme links
  * fixed test deps pkg
  * pr fixes
  * Update PULL_REQUEST_TEMPLATE.md
  * Fixed typo
  * replace armo by kubescape mentioned in urls
  * Removing mention of ARMO in the initi log print
  * use setters
  * Requesting PRs should be opened against the dev branch
  * Update README.md
  * Update README.md
  * Update README.md
  * Correction of grammatical errors
  * Added simple PR template
  * Updated the correct link on the discord button
  * Made changes in Readme file by adding discord link
  * update to kubescape org
  * chore: Add a Bug Report issue template
  * Add a feature request template
  * go mod tidy
  * change if order
  * log error
  * send mapNamespace to nuimber of resources in report
  * use ks namespace
  * removing unused function
  * updated dependencies pkgs
  * refactor!: httphandler: use Kubescape’s updated exported
    functions
  * chore: summeryhelpers.go → summaryhelpers.go
  * refactor!: resourcehandler: rename armoResources to ksResources
  * refactor!: resourcehandler: rename armoResources to ksResources
  * refactor!: resourcehandler: rename armoResources to ksResources
  * chore!: registryadaptors: rename armosec/v1 Go files
  * refactor!: registryadaptors: rename adaptor Armo to KS
  * refactor!: policyhandler/handlenotification.go: rename
    armoResources to ksResources
  * refactor!: opaprocessor/processorhandlerutils.go: rename
    getArmoObjects to getKSObjects
  * refactor!: core/submit.go: rename armoAPI to ksCloudAPI
  * refactor!: core/list: rename armoAPI to ksCloudAPI
  * refactor!: core/initutils.go: rename Armo to Kubescape Cloud
  * refactor!: core/delete.go: rename Armo to Kubescape
  * style: format ArmoResource comment
  * refactor!: rename MapArmoResource to MapKSResource
  * refactor!: rename "ArmoResources" to "KSResources"
  * chore!: scaninfo_test.go: remove commented out code
  * docs!: scaninfo.go: remove Armo mentions
  * chore!: remove commented out code from reportv2tov1
  * docs: rename CA in comments to Kubescape Cloud
  * refactor!: rename "ruleWithArmoOpaDependency" to
    "ruleWithKSOpaDependency"
  * refactor!: rename "ArmoResources" to "KSCloudResources"
  * docs: "armo" to "kubescape cloud" in customerloader comments
  * chore!: rename "armoapi.go" to "kscloudapi.go"
  * refactor(armoapiutils)!: rename "armoAPI" to "api"
  * refactor!: rename "armoAPI" receivers to "api"
  * refactor!: rename NewArmoAPICustomized to NewKSCloudCustomized
  * refactor!: rename "NewARMOAPIStaging" to "NewKSCloudAPIStaging"
  * refactor!: rename top-level global vars from "armo" to
    "ksCloud"
  * refactor!: rename "NewARMOAPIProd" to "NewKSCloudAPIProd"
    (Github tests ratelimit fails here)
  * refactor!: rename "NewArmoAPIDev" to "NewKSCloudAPIDev"
  * refactor!: rename "globalArmoAPIConnector" to
    "globalKSCloudAPIConnector"
  * refactor!: rename "GetArmoAPIConnector" to
    "etKSCloudAPIConnector"
  * refactor!: rename SetArmoAPIConnector to SetKSCloudAPIConnector
  * refactor!: rename ArmoAPI to KSCloudAPI
  * refactor!: rename "armo" to "kscloud" in RootInfo
  * refactor!: rename `armo` to `kubescape` in rootutils
* Mon Mar 13 2023 kastl@b1-systems.de
- Update to version 2.0.167:
  * Ignore markdown changes in workflows
  * Updated brew commands
* Mon Mar 13 2023 kastl@b1-systems.de
- Update to version 2.0.166:
  * fixed url displayed
* Mon Mar 13 2023 kastl@b1-systems.de
- Update to version 2.0.165:
  * adding gitlab support
  * fixed rbac submit
  * fixed link in readme
  * update readme
  * update failed image scanning message
  * chore: remove swagger.yaml at root
  * chore: regenerate swagger.yaml on latest
  * chore: clean up unused files
  * fix: add Swagger file to httphandler package
  * fix: update go module files
  * docs: add embedded Swagger spec
  * fix: tag proper JSON field in StatusQueryParams
  * refactor: clean up OpenAPI UI serving func
  * wip: feat: serve swagger doc
  * wip: docs: autogenerate Swagger specs
  * docs: add OpenAPI v3 spec
  * docs: swagger: extend GET scan endpoint info
  * docs: swagger: add OpenAPI V2 schema
  * adding UTMs
  * adding pprof
  * docs: update link for playground
  * cleaning the readme
  * adding heap api
  * helm chart name fix
  * Fix support account from ENV
  * include helm chart name
  * Support windows build
* Mon Mar 13 2023 kastl@b1-systems.de
- Update to version 2.0.164:
  * Update Makefile
* Mon Mar 13 2023 kastl@b1-systems.de
- Update to version 2.0.163:
  * remove URLs from python build file
  * use exteranl go logger
* Mon Mar 13 2023 kastl@b1-systems.de
- Update to version 2.0.162:
  * update go sum
  * Support relative paths in repo scanning
  * updated README
  * fix README
  * Replaced install_dependencie with Makefile, updated readme
  * updated workflow to run also on PR to dev
  * update build
  * update submodule commit
  * fix tests
  * missing tag for go test
  * update build process with libgit2
  * remove file commit information for windows
  * use git2go to get file commit information
  * update go deps
  * Decrease max report size
  * update URL
  * fixed tests
  * printing error when failed to load exceptions
  * Refactor for code aesthetics
  * update dev and stage urls
  * Modify the ScanningTarget to be a cluster or file
  * go mod tidy
  * Change "[info] Scanning. cluster:” to be dynamic by targetScan
  * Edit the noOfWorkers to be the minimum between the number of
    pods and 10
  * Ignore a case where the chan is closed
  * support in wokerpool in host sensor
  * Replacing the documentation links to the new URL
* Mon Mar 13 2023 kastl@b1-systems.de
- Update to version 2.0.161:
  * update report size limit to 4mb
  * use filepath join in unitests
  * update go mod
  * update readme
  * update readme
  * validate no workloads found
  * mixed merge
  * helm chart scanning
* Mon Mar 13 2023 kastl@b1-systems.de
- Update to version 2.0.160:
  * fixed printer
  * handke invalide files
* Mon Mar 13 2023 kastl@b1-systems.de
- Update to version 2.0.159:
  * remove error when reading yaml
  * Added host sensor new resources
  * fixed docker version
  * fixed typo
  * fixed test for win
  * fixed test
  * fixed test
  * ignore empty file
  * upgrade go version
  * fixed test
  * add nixos/nix and go install instructions
  * update dependencies
  * update pkg
  * fixed test
  * update opa pkg
  * fixed unitests
  * adding file path to wl
  * feat: add HTML as an output for scan results
  * fixed go mod
  * fixed build files
  * do not submit invalide account ID
  * validating slice length
  * Added gitignore for vscode git history files
  * Fixed web URL in git repo scanning
  * Fixed relative path in git repo scan
  * Fix backward competability of file scanning
  * Added default pattern, and type filtering in `listFiles`
  * Use clone in remote git repositories
  * ignore last commit
  * adding git data to file
  * support installation of a fixed version
  * moved testdata repo
  * beta url support
  * submit git scanning
  * adding client build
  * adding grafana dashboard
  * supporting github.repository_owner
  * updated commit date to time.Time and added length checking for
    remote URLs
  * implemented LocalGitRepository for working with a local git
    folder
* Mon Mar 13 2023 kastl@b1-systems.de
- Update to version 2.0.158:
  * Update README.md
* Mon Mar 13 2023 kastl@b1-systems.de
- Update to version 2.0.157:
  * chore: add maintenance message
* Mon Mar 13 2023 kastl@b1-systems.de
- Update to version 2.0.156:
  * print submit error
  * support secret key and account ID from cmd
  * adding logs
* Mon Mar 13 2023 kastl@b1-systems.de
- Update to version 2.0.155:
  * do not submit results every scan with Prometheus
  * loading from file fallback
  * update loading customer config
  * update auth url
  * load data from config.json
  * update readme
  * send prometheus triggering to queue
  * use channels for triggering scan
  * update status busy to support more than one req
  * fixed triggerd all frameworks
  * using Buildx in githubactions
  * update k8s-interface pkg
  * adding scan request log
  * go mod
  * update k8s-iface for http handler
  * update k8s-interface version
  * fixed import
  * adding status rest api
  * fix test
  * unit test for isEmptyImgVulns
  * unit test for isMaterNodeTaints
  * go mod
  * show skipped for scan without imgvuln
  * pull worker nodes based on taints
  * update go mod
  * support http and https for all endpoints
  * update k8s-interface
  * fix url
  * make parse func
  * support env with http
* Mon Mar 13 2023 kastl@b1-systems.de
- Update to version 2.0.154:
  * rm format-vers flag from examples
  * support control view
  * Updated readme - Lens extension
  * Updated readme - Lens extension
* Mon Mar 13 2023 kastl@b1-systems.de
- Update to version 2.0.153:
  * reprot ks version
  * return response object
  * check that fixCOmmand is not nul
  * go mod
  * support fixCOmmand
  * fixed saving error files
  * adding tests
  * docker user name
  * support keep in query
  * check tat control is not nil
  * check that control is present
  * use iface
  * update docker user name
  * return resp object from http req
  * update http handler
  * update go mod
  * sent git repo context
  * fix skipped for controlsd which use both armo and k8s resources
* Mon Mar 13 2023 kastl@b1-systems.de
- Update to version 2.0.152:
  * removed binary
* Mon Mar 13 2023 kastl@b1-systems.de
- Update to version 2.0.151:
  * update version check
  * rm context name
  * rm error msg
  * merge
  * change to ge contextname
  * fixed submit url
  * Call cmd pkg from root
  * update pkg struct
  * remove v1 format
  * adding logs
  * save policy in file
  * update resource table
  * format v2
  * report format version
  * convert score to int
  * support only one input
  * send file meta
  * update output
  * fix error msg for cloud
  * go mod
  * exit status 1
  * fix go mod
  * fix control input for yaml scan
  * register usesrs download from BE
  * update metrics
  * Added Severity Column with colored text
  * Improved grammatical mistakes and typos
  * mv cloud logic to k8s-interface
  * support yaml scan submit
* Mon Mar 28 2022 kastl@b1-systems.de
- Update to version 2.0.150:
  * udpate armo api types
  * use scan ID
  * fixed report sending
  * inserting scan source
  * adding githubusercontent tests
  * loading github token from env
  * fixed test
  * fixed url scanning
  * update error display
  * update readme
  * Add kubescape covarage
  * rm list initializtion
  * fix json printer
  * update opa-utils version
  * fix resources in report
  * update get context
  * udpate badges
  * adding vs code to readme
  * send scan metadata
  * json output
  * support frameworks from http request
  * fixed cmd init
  * fixes
  * refactor
  * fix table display
  * rm space
  * support status info
  * update prometheus format
  * add ks user to dockerfile
  * update Prometheus yaml
  * update output
  * junit format
  * update readme
  * adding docker build
  * change gif
  * add web & CLI Interfaces
  * update gif
  * Add new video to readme
  * adding tests to build
  * fixed unitest
  * add cautils to core
  * fixed output format
  * adding ks interface
  * split pkg
  * pass info in call
  * update cmd struct
  * update logger support
  * export to json
  * adding http handler
  * cli: added support for no color
  * Misc typo fixes
  * Add mock logger
  * udpate go mod
  * use semver.Compare for version check
  * update vulns input / output api
  * update readme
  * Adding readme and yaml
  * Prometheus support
* Mon Mar  7 2022 kastl@b1-systems.de
- Update to version 2.0.149:
  * call setTenant when submitting results
  * read linux kernel variables from host sensor
  * update roadmap
  * update maintainers
  * Update maintainers and roadmap
  * support submitting v2
  * update readme
  * auto complete examples
  * swapped print versions
  * json v2 support
  * Update junit support
  * added updated roadmap
  * extend exceptions support
  * update junit
  * fixed junit support
  * extent host-sensor support
  * Support float in fail-threshold
  * udpate packages
  * fixed help message
  * support output versions
  * support host sensor from local file
  * adding autocompletion
  * adding resource table
  * fix: argument validation for framework/control
  * ignore empty framewprks
  * handle errors
  * stage url
  * fix uuid high-risk vulnerability
  * fixed pretty-print v1, expand list support
  * init printer for all pkg
  * fixed discord banner
  * docs: describe support for pdf format output
  * feat(resulthandling): add support for pdf format output
* Tue Feb 22 2022 Johannes Kastl <kastl@b1-systems.de>
- new package kubescape: Kubescape is a K8s open-source tool providing a multi-cloud K8s single pane of glass, including risk analysis, security compliance, RBAC visualizer and image vulnerabilities scanning
